@@ -14,7 +14,7 @@ use Alien::Electron;
 use Valence::Object;
 
 
-our $VERSION = '0.200';
+our $VERSION = '0.201';
 
 
 sub new {
@@ -233,6 +233,8 @@ L<Electron|https://github.com/atom/electron> is chromium-based GUI application f
 
 Since valence is a generic RPC framework, none of the electron methods are hard-coded in the perl or javascript bridges. This means that all of the L<electron docs|https://github.com/atom/electron/tree/master/docs> are applicable and should be used as reference when developing with this module.
 
+B<NOTE>: This module depends on L<Alien::Electron> which will download and install the electron distribution appropriate for your operating system. On linux this depends on having the C<X11> environment variable set. See the L<Alien::Electron> documention for more details.
+
 =head1 DESIGN
 
 =head2 ASYNC PROGRAMMING
@@ -380,9 +382,9 @@ Currently this software has two tests, C<load.t> which verifies L<Valence> is in
 
 =head1 BACKWARDS COMPATIBILITY
 
-The extent to which this module is backwards-compatible depends on the underlying C<electron> project. The API was changed drastically between electron C<0.25.1> and C<1.0.1> (corresponding to L<Valence> releases C<0.100> and C<0.200>) so you will have to port your apps over. Sorry about that.
+The extent to which this module is backwards-compatible depends on the underlying C<electron> project. The API was changed drastically between electron C<0.25.1> and C<1.0.1> (corresponding to L<Valence> releases C<0.100> and C<0.200>) so you will have to port your apps over. Sorry about that. The changes are described in more detail in L<this electron blog post|http://electron.atom.io/blog/2015/11/17/electron-api-changes>.
 
-Presumably now that C<electron> has reached version C<1.0.0> it should now be more stable (but it's javascript so I wouldn't get my hopes up).
+Presumably now that C<electron> has reached version C<1.0.0> it should now be more stable.
 
 =head1 BUGS
 
